==> Smdn.Net.Imap4.Client-0.21.tar.bz2: Smdn.Net.Imap4.Client-0.21/Smdn.Net.Imap4/Smdn.Net.Imap4/ImapMailboxFlagList.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2008-2009 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;

namespace Smdn.Net.Imap4 {
  public class ImapMailboxFlagList : ImapStringEnumList<ImapMailboxFlag> {
    public ImapMailboxFlagList()
      : base(false)
    {
    }

    public ImapMailboxFlagList(IEnumerable<ImapMailboxFlag> flags)
      : base(false, flags)
    {
    }

    internal ImapMailboxFlagList(bool readOnly, IEnumerable<ImapMailboxFlag> flags)
      : base(readOnly, flags)
    {
    }
  }
}

==> Smdn.Net.Imap4.Client-0.32.tar.bz2: Smdn.Net.Imap4.Client-0.32/Smdn.Net.Imap4/Smdn.Net.Imap4/ImapMailboxFlagList.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2008-2010 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;

namespace Smdn.Net.Imap4 {
  public class ImapMailboxFlagList : ImapStringEnumList<ImapMailboxFlag>, IImapMailboxFlagSet {
    public ImapMailboxFlagList()
      : base(false)
    {
    }

    public ImapMailboxFlagList(IEnumerable<ImapMailboxFlag> flags)
      : base(false, flags)
    {
    }

    internal ImapMailboxFlagList(bool readOnly, IEnumerable<ImapMailboxFlag> flags)
      : base(readOnly, flags)
    {
    }

    public static ImapMailboxFlagList CreateReadOnlyEmpty()
    {
      return new ImapMailboxFlagList(true, new ImapMailboxFlag[0]);
    }

    public IImapMailboxFlagSet AsReadOnly()
    {
      if (IsReadOnly)
        return this;
      else
        return new ImapMailboxFlagList(true, this);
    }
  }
}
